@@ -1,6 +1,9 @@
+from logging import Logger
 import os
 from abc import ABC, abstractmethod
 
+from .kxy_logger import KxyLogger
+
 class BaseConfig(ABC):
     BussinessLog = False
     @abstractmethod
@@ -16,6 +19,7 @@ class BaseConfig(ABC):
     @abstractmethod
     def JWT_ALGORITHM(self):
         pass
+    AppLogger:KxyLogger = None
 
     def env_first(self):
         for name in [f for f in dir(self) if not callable(f) and not f.startswith('__')]:
