@@ -73,7 +73,7 @@ class BaseDal(Generic[T]):
         filters_copy= list(filters)
         for fieldName,v in filter_dict.items():
             filter = self._check_extend_field(fieldName,v.get())
-            if filter:
+            if not filter is None:
                 filters_copy.append(filter)
         return filters_copy
 
